<?php

namespace App\Http\Controllers;

use App\Post;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;

class PostController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $startTime = microtime(true);
        $posts = Post::orderBy('created_at', 'asc')->get();
        $postsCount = Post::all()->count();


        $time = microtime(true) - $startTime;
        return view('post.index', ['posts' => $posts, 'count' => $postsCount, 'time' => $time]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('post.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $start = microtime(true);

        $this->validate($request,[
            'title' => 'required',
            'text' => 'required'
        ]);

        for($i = 0; $i < 100; $i++) {
            $post = new Post;
            $post->title = $request->input('title');
            $post->text = $request->input('text');
            $post->category = $request->input('category');
            $post->user_id = auth()->user()->id;
            $post->save();
        }

        $time = microtime(true) - $start;
        //return $this->index();
        return redirect('post')->with('success', 'Time: ' . $time);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $post = Post::find($id);
        return view('post.show', ['post' => $post]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $post = Post::find($id);
        return view('post.edit', ['post' => $post]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $post = Post::find($id);
        $post->title = $request->input('title');
        $post->text = $request->input('text');
        $post->category = $request->input('category');
        $post->save();

        return redirect('/home')->with('success', 'Post created.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $post = Post::find($id);
        $post->delete();

        return redirect('post')->with('success', 'Post deleted.');
    }
}
